pub async fn append_rows<S: RawEventStore>(
store: &S,
id: &StreamKey,
rows: &[ConformanceRow],
)Expand description
Append rows to id as one batch on a fresh stream (expected = None).
pub async fn append_rows<S: RawEventStore>(
store: &S,
id: &StreamKey,
rows: &[ConformanceRow],
)Append rows to id as one batch on a fresh stream (expected = None).